@@ -108,7 +108,7 @@ class ApplicationApiTokens(object):
 
         Parameters:
         *  {string} applicationId - ID associated with the application
-        *  {hash} apiToken - API token information (https://api.losant.com/#/definitions/applicationApiTokenPost)
+        *  {hash} apiToken - API token information (https://api.losant.com/#/definitions/apiTokenPost)
         *  {string} losantdomain - Domain scope of request (rarely needed)
         *  {boolean} _actions - Return resource actions in response
         *  {boolean} _links - Return resource link in response
