@@ -475,6 +475,60 @@ class Device(object):
 
         return self.client.request("PATCH", path, params=query_params, headers=headers, body=body)
 
+    def payload_counts(self, **kwargs):
+        """
+        Returns payload counts for the time range specified for this device
+
+        Authentication:
+        The client must be configured with a valid api
+        access token to call this action. The token
+        must include at least one of the following scopes:
+        all.Application, all.Application.read, all.Organization, all.Organization.read, all.User, all.User.read, device.*, or device.payloadCounts.
+
+        Parameters:
+        *  {string} applicationId - ID associated with the application
+        *  {string} deviceId - ID associated with the device
+        *  {string} start - Start of range for payload count query (ms since epoch)
+        *  {string} end - End of range for payload count query (ms since epoch)
+        *  {string} losantdomain - Domain scope of request (rarely needed)
+        *  {boolean} _actions - Return resource actions in response
+        *  {boolean} _links - Return resource link in response
+        *  {boolean} _embedded - Return embedded resources in response
+
+        Responses:
+        *  200 - Payload counts, by type (https://api.losant.com/#/definitions/devicePayloadCounts)
+
+        Errors:
+        *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
+        *  404 - Error if device was not found (https://api.losant.com/#/definitions/error)
+        """
+
+        query_params = {"_actions": "false", "_links": "true", "_embedded": "true"}
+        path_params = {}
+        headers = {}
+        body = None
+
+        if "applicationId" in kwargs:
+            path_params["applicationId"] = kwargs["applicationId"]
+        if "deviceId" in kwargs:
+            path_params["deviceId"] = kwargs["deviceId"]
+        if "start" in kwargs:
+            query_params["start"] = kwargs["start"]
+        if "end" in kwargs:
+            query_params["end"] = kwargs["end"]
+        if "losantdomain" in kwargs:
+            headers["losantdomain"] = kwargs["losantdomain"]
+        if "_actions" in kwargs:
+            query_params["_actions"] = kwargs["_actions"]
+        if "_links" in kwargs:
+            query_params["_links"] = kwargs["_links"]
+        if "_embedded" in kwargs:
+            query_params["_embedded"] = kwargs["_embedded"]
+
+        path = "/applications/{applicationId}/devices/{deviceId}/payloadCounts".format(**path_params)
+
+        return self.client.request("GET", path, params=query_params, headers=headers, body=body)
+
     def remove_data(self, **kwargs):
         """
         Removes all device data for the specified time range. Defaults to all data.
