@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2020 Losant IoT, Inc.
+Copyright (c) 2021 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -306,7 +306,7 @@ class Org(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  200 - Payload counts, by type and source (https://api.losant.com/#/definitions/payloadCounts)
+        *  200 - Payload counts, by type and source (https://api.losant.com/#/definitions/payloadStats)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
